@@ -1,10 +1,11 @@
 
-package org.virtualbox_6_0.jaxws;
+package org.virtualbox_6_1.jaxws;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
+import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -35,6 +36,7 @@ import javax.xml.bind.annotation.XmlType;
 public class IGuestProcessInputNotifyEventGetStatusResponse {
 
     @XmlElement(required = true)
+    @XmlSchemaType(name = "string")
     protected ProcessInputStatus returnval;
 
     /**
