@@ -6,6 +6,7 @@ import java.util.List;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlRootElement;
+import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -35,6 +36,7 @@ import javax.xml.bind.annotation.XmlType;
 @XmlRootElement(name = "IKeyboard_getKeyboardLEDsResponse")
 public class IKeyboardGetKeyboardLEDsResponse {
 
+    @XmlSchemaType(name = "string")
     protected List<KeyboardLED> returnval;
 
     /**
